==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeXPathNodeList.h <==
// class gnu.xml.libxmlj.dom.GnomeXPathNodeList

// class file dependencies
// @dep_class dc963223a5acc464 gnu_xml_libxmlj_dom_GnomeXPathNodeList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeXPathNodeList_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeXPathNodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *);
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$free$300db1a5a8d912a8(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$free$300db1a5a8d912a8;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *);
	void	(*free$300db1a5a8d912a8)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, struct _jc_java_lang_Object$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *);
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods	gnu_xml_libxmlj_dom_GnomeXPathNodeList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs {
	struct _jc_java_lang_Object$object	*obj;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs	gnu_xml_libxmlj_dom_GnomeXPathNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeXPathNodeList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object {
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeXPathNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeXPathNodeList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeXPathNodeList.h <==
// class gnu.xml.libxmlj.dom.GnomeXPathNodeList

// class file dependencies
// @dep_class dc963223a5acc464 gnu_xml_libxmlj_dom_GnomeXPathNodeList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeXPathNodeList_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeXPathNodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$free$300db1a5a8d912a8(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$free$300db1a5a8d912a8;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *) _JC_JCNI_ATTR;
	void	(*free$300db1a5a8d912a8)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vmethods	gnu_xml_libxmlj_dom_GnomeXPathNodeList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs {
	struct _jc_java_lang_Object$object	*obj;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_refs	gnu_xml_libxmlj_dom_GnomeXPathNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeXPathNodeList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$object {
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$vtype _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeXPathNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeXPathNodeList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeXPathNodeList_H_ */
